==> haven_spc-2024.8.2.tar.gz: haven_spc-2024.8.2/docs/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = "haven"
copyright = "2022, Argonne National Laboratory"
author = "Mark Wolfman"

# The full version, including alpha/beta/rc tags
release = "0.1.0"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.inheritance_diagram",
    "sphinx.ext.graphviz",
    "autoapi.sphinx",
    "sphinx.ext.napoleon",
    "sphinx.ext.todo",
    "nbsphinx",
]

autoapi_modules = {"haven": None}
autodoc_typehints = "description"
autodoc_mock_imports = [
    "mergedeep",
]
napoleon_numpy_docstring = True

# Add custom pre-amble to the rendered jupyter notebooks
nbsphinx_prolog = r"""

This file is also available as an interactive jupyter notebook.

`Download this file as a notebook`_ (hint: right-click -> "save as").

.. _Download this file as a notebook: {{ env.doc2path(env.docname) }}

"""

nbsphinx_epilog = nbsphinx_prolog

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "classic"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = []

==> haven_spc-2025.2.1.tar.gz: haven_spc-2025.2.1/docs/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = "haven"
copyright = "2022, Argonne National Laboratory"
author = "Mark Wolfman"

# The full version, including alpha/beta/rc tags
release = "0.1.0"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.inheritance_diagram",
    "sphinx.ext.graphviz",
    "autoapi.sphinx",
    "sphinx.ext.napoleon",
    "sphinx.ext.todo",
    # "nbsphinx",
]

autoapi_modules = {"haven": None}
autodoc_typehints = "description"
autodoc_mock_imports = [
    "mergedeep",
]
napoleon_numpy_docstring = True

# Add custom pre-amble to the rendered jupyter notebooks
# nbsphinx_prolog = r"""

# This file is also available as an interactive jupyter notebook.

# `Download this file as a notebook`_ (hint: right-click -> "save as").

# .. _Download this file as a notebook: {{ env.doc2path(env.docname, base=None)|string }}

# """

# nbsphinx_epilog = nbsphinx_prolog

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "classic"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = []
